"""Custom show configurations for Plotly."""

import plotly.io as pio

custom_show_config = dict(
    displaylogo=False,
    scrollZoom=True,
    showTips=False,
    toImageButtonOptions=dict(
        format="png",
        scale=5,
    ),
)


def set_custom_show_config() -> None:
    pio.renderers["notebook"].config.update(custom_show_config)



__submodules__ = [
        "templates",
        "configs",
]

from .configs import custom_show_config, set_custom_show_config
from .templates import custom_white, set_custom_template
from ._version import __version__

__all__ = ["__version__",
           "custom_white", "set_custom_template",
           "custom_show_config", "set_custom_show_config"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['custom_plotly_templates']

package_data = \
{'': ['*']}

install_requires = \
['plotly>=5.10.0,<6.0.0']

setup_kwargs = {
    'name': 'custom-plotly-templates',
    'version': '0.1.0',
    'description': 'Custom templates and configurations for Plotly',
    'long_description': '# Custom plotly templates\n\nCustom templates and configurations for Plotly. Developed primary for my personal use.',
    'author': 'Ruslan Mukhametshin',
    'author_email': 'rusmux21@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/rusmux/custom-plotly-templates',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



"""Custom templates for Plotly."""

import plotly.graph_objects as go
import plotly.io as pio

custom_white = go.layout.Template(
    dict(
        data=dict(
            histogram=[go.Histogram(histnorm="probability")],
            pie=[go.Pie(textinfo="label+percent", insidetextfont_color="white")],
        ),
        layout=dict(
            font=dict(
                color="black",
                size=14,
            ),
            xaxis=dict(
                tickcolor="white",
                ticklen=5,
                ticks="outside",
            ),
            yaxis=dict(
                tickcolor="white",
                ticklen=5,
                ticks="outside",
            ),
            legend=dict(
                itemclick="toggleothers",
                itemdoubleclick="toggle",
            ),
            margin=dict(t=100, b=40),
            dragmode="pan",
            modebar_remove=["autoScale", "lasso2d", "select"],
            modebar_activecolor="#F39C12",
        ),
    )
)

pio.templates["custom_white"] = custom_white


def set_custom_template(template: str) -> None:
    if template == "custom_white":
        pio.templates.default = "plotly_white+custom_white"
    else:
        raise ValueError(f"\"{template}\" is not a valid template. "
                         f"Template must be one of: [\"custom_white\"]")
